
#ifndef _RTEMS_NETWORKCONFIG_H_
#define _RTEMS_NETWORKCONFIG_H_

/*
 *  The following will normally be set by the BSP if it supports
 *  a single network device driver.  In the event, it supports
 *  multiple network device drivers, then the user's default
 *  network device driver will have to be selected by a BSP
 *  specific mechanism.
 */

#ifndef RTEMS_BSP_NETWORK_DRIVER_NAME
#warning "RTEMS_BSP_NETWORK_DRIVER_NAME is not defined"
#define RTEMS_BSP_NETWORK_DRIVER_NAME "no_network1"
#endif

#ifndef RTEMS_BSP_NETWORK_DRIVER_ATTACH
#warning "RTEMS_BSP_NETWORK_DRIVER_ATTACH is not defined"
#define RTEMS_BSP_NETWORK_DRIVER_ATTACH 0
#endif

/*
 * ANT gets network parameters from bootp server
 */ 
#define RTEMS_USE_BOOTP 

#include <bsp.h>

/*
 * Pick an ethernet address
 */
#define RTEMS_SET_ETHERNET_ADDRESS
#if (defined (RTEMS_SET_ETHERNET_ADDRESS))
static char ethernet_address[6] = { 0x00, 0x80, 0x7F, 0x22, 0x61, 0x77 };
#endif

#ifdef RTEMS_USE_LOOPBACK 
extern void rtems_bsdnet_loopattach();
static struct rtems_bsdnet_ifconfig loopback_config = {
	"lo0",							/* name */
	rtems_bsdnet_loopattach,	/* attach function */
	NULL,								/* link to next interface */
	"127.0.0.1",					/* IP address */
	"255.0.0.0",					/* IP net mask */
};
#endif

/*
 * Default network interface
 */
static struct rtems_bsdnet_ifconfig netdriver_config = {
	RTEMS_BSP_NETWORK_DRIVER_NAME,		/* name */
	RTEMS_BSP_NETWORK_DRIVER_ATTACH,		/* attach function */

#ifdef RTEMS_USE_LOOPBACK 
	&loopback_config,							/* link to next interface */
#else
	NULL,											/* No more interfaces */
#endif

#if (defined (RTEMS_USE_BOOTP))
	NULL,											/* BOOTP supplies IP address */
	NULL,											/* BOOTP supplies IP net mask */
#else
	"147.24.194.44",							/* IP address */
	"255.255.255.0",							/* IP net mask */
#endif /* !RTEMS_USE_BOOTP */

#if (defined (RTEMS_SET_ETHERNET_ADDRESS))
	ethernet_address,               		/* Ethernet hardware address */
#else
	NULL,                           		/* Driver supplies hardware address */
#endif
	0												/* Use default driver parameters */
};

/*
 * Network configuration
 */
struct rtems_bsdnet_config rtems_bsdnet_config = {
	&netdriver_config,

#if (defined (RTEMS_USE_BOOTP))
	rtems_bsdnet_do_bootp,
#else
	NULL,
#endif

	0,							/* Default network task priority */
	0,							/* Default mbuf capacity */
	0,							/* Default mbuf cluster capacity */

#if (!defined (RTEMS_USE_BOOTP))
	"protobeast",			/* Host name */
	"protobeast.com",		/* Domain name */
	"147.24.194.45",		/* Gateway */
	"147.24.194.45",		/* Log host */
	{"147.24.194.45" },	/* Name server(s) */
	{"147.24.194.45" },	/* NTP server(s) */
#endif
};

/*
 * For TFTP test application
 */
#if (!defined (RTEMS_USE_BOOTP))
#define RTEMS_TFTP_TEST_HOST_NAME "147.24.194.45"
#define RTEMS_TFTP_TEST_FILE_NAME "tftptest"
#endif

#endif /* _RTEMS_NETWORKCONFIG_H_ */
